@@ -6,7 +6,7 @@ from .structures import AddrMap, Pca
 from .structures import P, C, A
 from .matcher import Matcher
 
-VERSION = (0, 5, 4)
+VERSION = (0, 5, 5)
 
 __version__ = ".".join([str(x) for x in VERSION])
 
@@ -125,8 +125,9 @@ def transform_text_with_addrs(text_with_addrs, index=None, pos_sensitive=False,
              umap: 当只有区的信息时， 且该区存在同名时， 指定该区具体是哪一个，字典的 key 为区名，value 为 adcode， 比如 {"朝阳区": "110105"}
     """
     import pandas as pd
-    result = pd.DataFrame(_extract_addrs(text_with_addrs, pos_sensitive, umap, truncate_pos=False,
-                                         new_entry_when_not_belong=True),
+    result = pd.DataFrame(filter(lambda record: record[_ADCODE] is not None,
+                                 _extract_addrs(text_with_addrs, pos_sensitive, umap, truncate_pos=False,
+                                         new_entry_when_not_belong=True)),
                           index=index)
     return tidy_order(result, pos_sensitive)
 
